pub trait Destination {
type Event;
// Required method
fn send(&self, event: Self::Event);
}Expand description
The implementing actor is able to receive and handle messages. Typically, it’s the sending end of the channel, whose other end is inside an event loop.