fn get_directory_string(
content_purpose: ContentPurpose,
overlay: Option<&str>,
) -> StringExpand description
Returns the directory string where the layout should be looked up, including the slash.
fn get_directory_string(
content_purpose: ContentPurpose,
overlay: Option<&str>,
) -> StringReturns the directory string where the layout should be looked up, including the slash.